@@ -1,7 +1,7 @@
 from django.contrib.auth.models import Group
 from samklang_pages.models import Page
 from django.utils.translation import ugettext_lazy as _
-from samklang_utils.forms import MarkdownTextarea#, GroupField
+from samklang_utils.forms import MarkdownTextarea
 import floppyforms as forms
 
 class PageForm(forms.ModelForm):
@@ -15,7 +15,6 @@ class PageForm(forms.ModelForm):
                 " underscores, dashes or slashes."),
             )
     group = forms.ModelChoiceField(Group.objects, empty_label=_("Public"), required=False, label=_("Read permission"))
-    #group = GroupField(Group.objects, initial='0')
 
     class Meta:
         model = Page
